@@ -1,5 +1,5 @@
 enum asmStatementIndex {
-  asmObjProcIdx, 
+  asmObjProcIdx,
   asmEvalIdx,
   asmDuplicateObjIdx,
   asmIncrIntIdx,
@@ -24,7 +24,7 @@ enum asmStatementIndex {
 };
 
 static CONST char *asmStatementNames[] = {
-  "cmd", 
+  "cmd",
   "eval",
   "duplicateObj",
   "incrInt",
@@ -49,26 +49,26 @@ static CONST char *asmStatementNames[] = {
   NULL
 };
 
-enum asmStatmentArgTypeIndex {
-  asmStatementArgTypeArgIdx, 
-  asmStatementArgTypeArgvIdx, 
-  asmStatementArgTypeInstructionIdx, 
-  asmStatementArgTypeIntIdx, 
-  asmStatementArgTypeObjIdx, 
-  asmStatementArgTypeResultIdx, 
+enum asmStatementArgTypeIndex {
+  asmStatementArgTypeArgIdx,
+  asmStatementArgTypeArgvIdx,
+  asmStatementArgTypeInstructionIdx,
+  asmStatementArgTypeIntIdx,
+  asmStatementArgTypeObjIdx,
+  asmStatementArgTypeResultIdx,
   asmStatementArgTypeSlotIdx,
   asmStatementArgTypeVarIdx
 };
 
 static CONST char *asmStatementArgType[] = {
-  "arg", 
-  "argv", 
-  "instruction", 
-  "int", 
-  "obj", 
-  "result", 
-  "slot", 
-  "var", 
+  "arg",
+  "argv",
+  "instruction",
+  "int",
+  "obj",
+  "result",
+  "slot",
+  "var",
   NULL};
 
 static CONST char *asmStatementCmdType[]         = {"arg", "obj", "result", "var", NULL};
@@ -139,8 +139,8 @@ static AsmStatementInfo asmStatementInfo[] = {
  *----------------------------------------------------------------------
  */
 
-static int 
-AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj, 
+static int
+AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	      int nrArgs, Tcl_Obj *asmObj, AsmCompiledProc **retAsmProc) {
   AsmPatches patchArray[100], *patches = &patchArray[0], *patchPtr; // TODO: make me dynamic
   Tcl_Command cmd;
@@ -153,7 +153,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 
   assert(nameObj != NULL);
   procName = ObjStr(nameObj);
-  
+
   if (Tcl_ListObjGetElements(interp, asmObj, &oc, &ov) != TCL_OK) {
     return NsfPrintError(interp, "Asm code is not a valid list");
   }
@@ -168,42 +168,42 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
   for (i = 0; i < oc; i++) {
     int index, offset, wordOc;
     Tcl_Obj *lineObj = ov[i], **wordOv;
-    
+
     if (Tcl_ListObjGetElements(interp, lineObj, &wordOc, &wordOv) != TCL_OK) {
-      return NsfPrintError(interp, 
-			   "Asm: line is not a well-formed asm instruction: %s", 
+      return NsfPrintError(interp,
+			   "Asm: line is not a well-formed asm instruction: %s",
 			   ObjStr(lineObj));
     }
 
     result = Tcl_GetIndexFromObj(interp, wordOv[0], asmStatementNames, "asm instruction", 0, &index);
     if (result != TCL_OK) {
-      return NsfPrintError(interp, 
-			   "Asm: line is not a valid asm instruction: word %s, line %s", 
+      return NsfPrintError(interp,
+			   "Asm: line is not a valid asm instruction: word %s, line %s",
 			   ObjStr(wordOv[0]), ObjStr(lineObj));
     }
 
     offset = (asmStatementInfo[index].flags & ASM_INFO_SKIP1) ? 2 : 1;
 
     if ((asmStatementInfo[index].flags & ASM_INFO_PAIRS) && (wordOc-offset) % 2 == 1) {
-      return NsfPrintError(interp, "Asm: argument list of cmd must contain pairs: %s", 
+      return NsfPrintError(interp, "Asm: argument list of cmd must contain pairs: %s",
 			   ObjStr(lineObj));
     }
 
-    if (asmStatementInfo[index].minArgs > -1 
+    if (asmStatementInfo[index].minArgs > -1
 	&& wordOc < asmStatementInfo[index].minArgs) {
-      return NsfPrintError(interp, "Asm: statement must contain at least %d words: %s", 
+      return NsfPrintError(interp, "Asm: statement must contain at least %d words: %s",
 			   asmStatementInfo[index].minArgs, ObjStr(lineObj));
     }
 
     if (asmStatementInfo[index].maxArgs > -1
 	&& wordOc > asmStatementInfo[index].maxArgs) {
-      return NsfPrintError(interp, "Asm: statement must contain at most %d words: %s", 
+      return NsfPrintError(interp, "Asm: statement must contain at most %d words: %s",
 			   asmStatementInfo[index].maxArgs, ObjStr(lineObj));
     }
 
     if (asmStatementInfo[index].argTypes) {
-      result = AsmInstructionArgvCheck(interp, offset, wordOc, 
-				       asmStatementInfo[index].argTypes, 
+      result = AsmInstructionArgvCheck(interp, offset, wordOc,
+				       asmStatementInfo[index].argTypes,
 				       nrLocalObjs, oc, wordOv, lineObj);
       if (unlikely(result != TCL_OK)) {return result;}
     }
@@ -238,14 +238,14 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
       /* {cmd ::set slot 0 slot 2} */
       cmd = Tcl_GetCommandFromObj(interp, wordOv[1]);
       if (cmd == NULL) {
-	return NsfPrintError(interp, 
-			     "Asm: cmd is not a valid tcl command: %s\n", 
+	return NsfPrintError(interp,
+			     "Asm: cmd is not a valid Tcl command: %s\n",
 			     Tcl_GetString( wordOv[1]));
       }
       break;
 
-   /* begin generated code */  
-   
+   /* begin generated code */
+
    /* end generated code */
 
     default:
@@ -254,8 +254,8 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
   }
 
   nrAsmInstructions ++;
-  fprintf(stderr, "%s: nrAsmInstructions %d nrLocalObjs %d nrArgs %d argvArgs %d => data %d\n", 
-	  procName, nrAsmInstructions, nrLocalObjs, nrArgs, totalArgvArgs, 
+  fprintf(stderr, "%s: nrAsmInstructions %d nrLocalObjs %d nrArgs %d argvArgs %d => data %d\n",
+	  procName, nrAsmInstructions, nrLocalObjs, nrArgs, totalArgvArgs,
 	  nrLocalObjs + nrArgs + totalArgvArgs );
 
   /*
@@ -274,8 +274,8 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
   //fprintf(stderr, "args = %ld\n", proc->slots - proc->locals);
 
   AsmLocalsAlloc(proc, nrArgs + nrLocalObjs);
-  /* when freeing, we need something like 
-    for (i=0; i < nrArgs + nrLocalObjs; i++) { 
+  /* when freeing, we need something like
+    for (i=0; i < nrArgs + nrLocalObjs; i++) {
       if (proc->slotFlags[i] & ASM_SLOT_MUST_DECR) {Tcl_DecrRefCount(proc->slots[i]); }
     }
   */
@@ -289,7 +289,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
   for (i = 0; i < oc; i++) {
     int index, offset, cArgs, argc, codeIndex, argvIndex, j;
     Tcl_Obj *lineObj = ov[i], **argv;
-    
+
     Tcl_ListObjGetElements(interp, lineObj, &argc, &argv);
     Tcl_GetIndexFromObj(interp, argv[0], asmStatementNames, "asm instruction", 0, &index);
 
@@ -301,7 +301,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
     } else if (cArgs == NR_PAIRS1) {
       cArgs = 1 + (argc-offset) / 2;
     }
-    
+
     switch (index) {
 
     case asmObjProcIdx:
@@ -362,7 +362,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	  proc->slotFlags[currentSlot] |= ASM_SLOT_IS_INTEGER;
 	  currentSlot ++;
 	}
-      
+
       break;
 
    case asmJumpIdx:
@@ -404,7 +404,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	{ Tcl_Command cmd = NULL;
 	  NsfObject *object = NULL;
 	  AsmResolverInfo *resInfo;
-	  
+	
 	  if (strncmp(ObjStr(inst->argv[1]), "::nsf::methods::", 16) == 0) {
 	    cmd = Tcl_GetCommandFromObj(interp, inst->argv[1]);
 	    //fprintf(stderr, "%s: asmMethod cmd '%s' => %p\n", procName, ObjStr(inst->argv[1]), cmd);
@@ -422,20 +422,20 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	    AsmInstructionSetCmd(inst, asmMethodDelegateDispatch11);
 	  } else if (cmd != 0) {
 	    inst->clientData = cmd;
-	  } else {	  
+	  } else {	
 	    inst->clientData = NULL;
 	  }
 	}
-      
+
       break;
 
    case asmMethodSelfDispatchIdx:
 
 	inst = AsmInstructionNew(proc, asmMethodSelfDispatch, cArgs);
 	if (cArgs > 0) {AsmInstructionArgvSet(interp, offset, argc, 0, inst, proc, argv, 0);}
-	{ Tcl_Command cmd = NULL;	  
+	{ Tcl_Command cmd = NULL;	
 	  AsmResolverInfo *resInfo;
-	  
+	
 	  if (strncmp(ObjStr(inst->argv[0]), "::nsf::methods::", 16) == 0) {
 	    cmd = Tcl_GetCommandFromObj(interp, inst->argv[0]);
 	    if (cmd != 0) {
@@ -450,7 +450,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	  resInfo->proc = proc;
 	  inst->clientData = resInfo;
 	}
-      
+
       break;
 
    case asmNoopIdx:
@@ -465,7 +465,7 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	Tcl_IncrRefCount(proc->slots[currentSlot]);
 	proc->slotFlags[currentSlot] |= ASM_SLOT_MUST_DECR;
 	currentSlot ++;
-      
+
       break;
 
    case asmSelfIdx:
@@ -537,20 +537,20 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
 	patches->sourceAsmInstruction = codeIndex;
 	patches->argvIndex = argvIndex;
 	patches++;
-      
+
       break;
 
    case asmVarIdx:
 
 	proc->slots[currentSlot] = NULL;
 	currentSlot ++;
-      
+
       break;
 
 
       /* end generated code */
   }
-      
+
     if ((asmStatementInfo[index].flags & ASM_INFO_DECL) == 0) {
       currentAsmInstruction ++;
     }
@@ -560,17 +560,17 @@ AsmAssemble(ClientData cd, Tcl_Interp *interp, Tcl_Obj *nameObj,
    * add END instruction
    */
   inst = AsmInstructionNew(proc, NULL, 0);
-  
+
   /*
    * All addresses are determined, apply the argv patches triggered
    * from above.
    */
 
   for (patchPtr = &patchArray[0]; patchPtr < patches; patchPtr++) {
-    fprintf(stderr, "wanna patch code[%d]->argv = code[%d]->argv[%d]\n",
+    fprintf(stderr, "want to patch code[%d]->argv = code[%d]->argv[%d]\n",
 	    patchPtr->targetAsmInstruction, patchPtr->sourceAsmInstruction, patchPtr->argvIndex);
     /* set the argument vector of code[1] to the address of code[4]->argv[1] */
-    (&proc->code[patchPtr->targetAsmInstruction])->argv = 
+    (&proc->code[patchPtr->targetAsmInstruction])->argv =
       &(&proc->code[patchPtr->sourceAsmInstruction])->argv[patchPtr->argvIndex];
   }
 
