@@ -2,7 +2,7 @@
 # -*- Tcl -*-
 #
 # C-Code generator to generate stubs to handle all objv-parsing from
-# an simple interface definition language. This guarantees consistent
+# a simple interface definition language. This guarantees consistent
 # handling of input argument types, consistent error messages in case
 # of failures and eases documentation.
 #
@@ -75,11 +75,11 @@ typedef enum {@enums@} @name@Idx_t;
 @globalOpts@
 static int ConvertTo@name@(Tcl_Interp *interp, Tcl_Obj *objPtr, Nsf_Param const *pPtr,
 			    ClientData *clientData, Tcl_Obj **outObjPtr) {
-  int index, result;
+  int pos, result;
   @localOpts@
   (void)pPtr;
-  result = Tcl_GetIndexFromObj(interp, objPtr, @optsName@, "@typeName@", 0, &index);
-  *clientData = (ClientData) INT2PTR(index + 1);
+  result = Tcl_GetIndexFromObj(interp, objPtr, @optsName@, "@typeName@", 0, &pos);
+  *clientData = (ClientData) INT2PTR(pos + 1);
   *outObjPtr = objPtr;
   return result;
 }
