@@ -4,9 +4,9 @@
  *      Declarations of the internally used API Functions of the Next
  *      Scripting Framework.
  *
- *  Copyright (C) 1999-2017 Gustaf Neumann (a, b)
+ *  Copyright (C) 1999-2018 Gustaf Neumann (a, b)
  *  Copyright (C) 1999-2007 Uwe Zdun (a, b)
- *  Copyright (C) 2011-2017 Stefan Sobernig (b)
+ *  Copyright (C) 2011-2018 Stefan Sobernig (b)
  *
  * (a) University of Essen
  *     Specification of Software Systems
@@ -19,7 +19,7 @@
  *     Vienna, Austria
  *
  * This work is licensed under the MIT License
- * http://www.opensource.org/licenses/MIT
+ * https://www.opensource.org/licenses/MIT
  *
  * Copyright:
  *
@@ -46,11 +46,6 @@
 #ifndef _nsf_int_h_
 #define _nsf_int_h_
 
-#if defined(HAVE_STDINT_H)
-# define HAVE_INTPTR_T
-# define HAVE_UINTPTR_T
-#endif
-
 /*
  * Well behaved compiler with C99 support should define __STDC_VERSION__
  */
@@ -67,6 +62,31 @@
 # define NSF_HAVE_C99
 #endif
 
+#if defined(_MSC_VER) && _MSC_VER < 1800
+# undef HAVE_INTTYPES_H
+#else
+# define HAVE_INTTYPES_H 1
+#include <inttypes.h>
+#endif
+
+#if !defined(HAVE_INTTYPES_H)
+# if !defined(__PRIPTR_PREFIX)
+#  if defined(_LP64) || defined(_I32LPx) || defined(HAVE_64BIT) || defined(_WIN64) || defined(_WIN32)
+#   if defined(_WIN32)
+#    define __PRIPTR_PREFIX "ll"
+#   else
+#    define __PRIPTR_PREFIX "l"
+#   endif
+#  else
+#   define __PRIPTR_PREFIX
+#  endif
+# endif
+# ifndef PRIxPTR
+#  define PRIxPTR    __PRIPTR_PREFIX "x"
+# endif
+#endif
+
+
 /*
  * Boolean type "bool" and constants
  */
@@ -106,7 +126,7 @@ typedef int bool;
  *
  * Note: It is sufficient to test for __MINGW32__ to trap all MinGW
  * tool chains, including 64bit versions. See
- * http://sourceforge.net/p/predef/wiki/Compilers/#mingw-and-mingw-w64
+ * https://sourceforge.net/p/predef/wiki/Compilers/#mingw-and-mingw-w64
  */
 
 #if defined(__MINGW32__) && !defined(__USE_MINGW_ANSI_STDIO)
@@ -291,7 +311,14 @@ typedef struct NsfMemCounter {
 #  define USE_MALLOC
 #endif
 
-#if defined(__GNUC__) && !defined(USE_ALLOCA) && !defined(USE_MALLOC)
+#if 1
+# define NSF_STACK_ALLOCATED_OBJV 32
+# define ALLOC_ON_STACK(type,n,var) \
+  type *(var); type stack_allocated_##var[NSF_STACK_ALLOCATED_OBJV];	\
+  if (likely((n) < NSF_STACK_ALLOCATED_OBJV)) { (var) = &stack_allocated_##var[0]; } else { (var) = NEW_ARRAY(type, (n)); }
+# define FREE_ON_STACK(type, var) \
+  if ((var) != &stack_allocated_##var[0]) { FREE(type *, var);}
+#elif defined(__GNUC__) && !defined(USE_ALLOCA) && !defined(USE_MALLOC)
 # if !defined(NDEBUG)
 #  define ALLOC_ON_STACK(type,n,var) \
   int __##var##_count = (n); type __##var[(n)+2];			\
@@ -355,17 +382,17 @@ typedef struct NsfMemCounter {
 #define ObjTypeStr(obj) (((obj)->typePtr != NULL) ? ((obj)->typePtr->name) : "NONE")
 #define ClassName(cl) (((cl) != NULL) ? ObjStr((cl)->object.cmdName) : "NULL")
 #define ClassName_(cl) (ObjStr((cl)->object.cmdName))
-#define ObjectName(obj) (((obj) != NULL) ? ObjStr((obj)->cmdName) : "NULL")
-#define ObjectName_(obj) (ObjStr((obj)->cmdName))
+#define ObjectName(object) (((object) != NULL) ? ObjStr((object)->cmdName) : "NULL")
+#define ObjectName_(object) (ObjStr((object)->cmdName))
 
 #ifdef OBJDELETION_TRACE
-# define PRINTOBJ(ctx,obj) \
+# define PRINTOBJ(ctx,object) \
   fprintf(stderr, "  %s %p %s oid=%p teardown=%p destroyCalled=%d\n", \
-	  (ctx),(obj),(obj)->teardown?ObjStr((obj)->cmdName):"(deleted)", \
-	  (obj)->id, (obj)->teardown,                                 \
-	  ((obj)->flags & NSF_DESTROY_CALLED))
+	  (ctx),(object),(object)->teardown?ObjStr((object)->cmdName):"(deleted)", \
+	  (object)->id, (object)->teardown,                                 \
+	  ((object)->flags & NSF_DESTROY_CALLED))
 #else
-# define PRINTOBJ(ctx,obj)
+# define PRINTOBJ(ctx,object)
 #endif
 
 /*
@@ -527,6 +554,7 @@ typedef struct NsfStringIncrStruct {
 #define NSF_KEEP_CALLER_SELF               0x0400u
 #define NSF_PER_OBJECT_DISPATCH            0x0800u
 #define NSF_HAS_PER_OBJECT_SLOTS           0x1000u
+#define NSF_IS_AUTONAMED                   0x2000u
 /* deletion states */
 #define NSF_DESTROY_CALLED_SUCCESS       0x010000u /* requires flags to be int, not short */
 #define NSF_DURING_DELETE                0x020000u
@@ -568,14 +596,14 @@ typedef struct NsfStringIncrStruct {
 #define NSF_METHODTYPE_ALL       NSF_METHODTYPE_SCRIPTED|NSF_METHODTYPE_BUILTIN|NSF_METHODTYPE_OBJECT
 
 
-#define NsfObjectSetClass(obj) \
-	(obj)->flags |= NSF_IS_CLASS
-#define NsfObjectClearClass(obj) \
-	(obj)->flags &= ~NSF_IS_CLASS
-#define NsfObjectIsClass(obj) \
-	((obj)->flags & NSF_IS_CLASS)
-#define NsfObjectToClass(obj) \
-	(NsfClass *)((((NsfObject *)obj)->flags & NSF_IS_CLASS) ? obj : NULL)
+#define NsfObjectSetClass(object) \
+	(object)->flags |= NSF_IS_CLASS
+#define NsfObjectClearClass(object) \
+	(object)->flags &= ~NSF_IS_CLASS
+#define NsfObjectIsClass(object) \
+	((object)->flags & NSF_IS_CLASS)
+#define NsfObjectToClass(object) \
+	(NsfClass *)((((NsfObject *)object)->flags & NSF_IS_CLASS) ? object : NULL)
 
 
 /*
@@ -668,8 +696,8 @@ typedef struct NsfProcClientData {
   Tcl_Command    cmd;
   Tcl_Command    wrapperCmd;
   NsfParamDefs  *paramDefs;
-  Tcl_Namespace *origNsPtr;
   unsigned int   flags;
+  Tcl_Interp    *interp;
 } NsfProcClientData;
 
 typedef enum SystemMethodsIdx {
@@ -755,7 +783,7 @@ typedef enum {
   /* Partly redefined Tcl commands; leave them together at the end */
   NSF_EXPR, NSF_FORMAT, NSF_INFO_BODY, NSF_INFO_FRAME, NSF_INTERP,
   NSF_STRING_IS, NSF_EVAL, NSF_DISASSEMBLE,
-  NSF_RENAME 
+  NSF_RENAME
 } NsfGlobalNames;
 #if !defined(NSF_C)
 EXTERN const char *NsfGlobalStrings[];
@@ -788,8 +816,8 @@ const char *NsfGlobalStrings[] = {
 
 #define NsfGlobalObjs RUNTIME_STATE(interp)->methodObjNames
 
-/* 
- * Interface for Tcl_Obj types 
+/*
+ * Interface for Tcl_Obj types
  */
 EXTERN Tcl_ObjType NsfMixinregObjType;
 EXTERN int NsfMixinregGet(Tcl_Interp *interp, Tcl_Obj *obj, NsfClass **classPtr, Tcl_Obj **guardObj)
@@ -805,8 +833,8 @@ EXTERN NsfClassOpt *NsfRequireClassOpt(NsfClass *class)
   nonnull(1) returns_nonnull;
 
 
-/* 
- * Next Scripting ShadowTclCommands 
+/*
+ * Next Scripting ShadowTclCommands
  */
 typedef struct NsfShadowTclCommandInfo {
   TclObjCmdProcType proc;
@@ -1058,22 +1086,22 @@ EXTERN Tcl_ObjCmdProc NsfObjDispatch;
 EXTERN void NsfCleanupObject_(NsfObject *object) nonnull(1);
 
 #if defined(NSFOBJ_TRACE)
-# define NsfObjectRefCountIncr(obj)					\
-  ((NsfObject *)obj)->refCount++;					\
-  fprintf(stderr, "RefCountIncr %p count=%d %s\n", obj, ((NsfObject *)obj)->refCount, \
-	((NsfObject *)obj)->cmdName?ObjStr(((NsfObject *)obj)->cmdName):"no name"); \
-  MEM_COUNT_ALLOC("NsfObject.refCount", obj)
-# define NsfObjectRefCountDecr(obj)					\
-  (obj)->refCount--;							\
-  fprintf(stderr, "RefCountDecr %p count=%d\n", obj, obj->refCount);	\
-  MEM_COUNT_FREE("NsfObject.refCount", obj)
+# define NsfObjectRefCountIncr(object)		\
+  ((NsfObject *)(object))->refCount++;		\
+  fprintf(stderr, "RefCountIncr %p count=%d %s\n", (object), ((NsfObject *)(object))->refCount, \
+	  ((NsfObject *)object)->cmdName?ObjStr(((NsfObject *)(object))->cmdName):"no name");   \
+  MEM_COUNT_ALLOC("NsfObject.refCount", (object))
+# define NsfObjectRefCountDecr(object)					\
+  (object)->refCount--;							\
+  fprintf(stderr, "RefCountDecr %p count=%d\n", (object), (object)->refCount); \
+  MEM_COUNT_FREE("NsfObject.refCount", (object))
 #else
-# define NsfObjectRefCountIncr(obj)           \
-  (obj)->refCount++;                            \
-  MEM_COUNT_ALLOC("NsfObject.refCount", obj)
-# define NsfObjectRefCountDecr(obj)           \
-  (obj)->refCount--;                            \
-  MEM_COUNT_FREE("NsfObject.refCount", obj)
+# define NsfObjectRefCountIncr(object)          \
+  (object)->refCount++;                         \
+  MEM_COUNT_ALLOC("NsfObject.refCount", (object))
+# define NsfObjectRefCountDecr(object)		\
+  (object)->refCount--;				\
+  MEM_COUNT_FREE("NsfObject.refCount", (object))
 #endif
 
 /*
@@ -1338,7 +1366,7 @@ char *strnstr(const char *buffer, const char *needle, size_t buffer_len) pure;
    falls back to the prefixed version, if available, and provides a
    more general fallback to a simple assignment; this is primarily for
    MSVC; admittedly, this simplification is not generally portable to
-   platform/compiler combos other then x86, but the best I can think of right
+   platform/compiler combos other than x86, but the best I can think of right
    now. One might constrain the assignment-fallback to a platform and
    leave va_copy undefined in uncaught platform cases (?).
 */
@@ -1357,7 +1385,7 @@ char *strnstr(const char *buffer, const char *needle, size_t buffer_len) pure;
 #define vsnprintf _vsnprintf
 #endif
 
-/* 
+/*
  * There are six whitespace characters in Tcl, which serve as element
  * separators in string representations of Tcl lists. See tclUtil.c
  */
@@ -1368,4 +1396,7 @@ char *strnstr(const char *buffer, const char *needle, size_t buffer_len) pure;
 #define NsfMax(a,b) ((a) > (b) ? a : b)
 #define NsfMin(a,b) ((a) < (b) ? a : b)
 
+#define NsfCallStackFindLastInvocation(interp, offset, framePtrPtr) \
+  NsfCallStackFindCallingContext((interp), (offset), (framePtrPtr), NULL)
+
 #endif /* _nsf_int_h_ */
