@@ -11,7 +11,7 @@
  * A-1020, Welthandelsplatz 1
  * Vienna, Austria
  *
- * This work is licensed under the MIT License http://www.opensource.org/licenses/MIT
+ * This work is licensed under the MIT License https://www.opensource.org/licenses/MIT
  *
  * Copyright:
  *
@@ -43,7 +43,7 @@
  *
  *  NsfMethodObjType Tcl_Obj type --
  *
- *      The NsfMethodObjType is an Tcl_Obj type carrying the result of
+ *      The NsfMethodObjType is a Tcl_Obj type carrying the result of
  *      a method lookup. We define two types (NsfInstanceMethodObjType
  *      and NsfObjectMethodObjType) sharing their implementation. The
  *      type setting function NsfMethodObjSet() receives the intended
@@ -190,7 +190,7 @@ NsfMethodObjSet(
  *
  *  NsfFlagObjType --
  *
- *      The NsfFlagObjType is an Tcl_Obj type carrying the result of a
+ *      The NsfFlagObjType is a Tcl_Obj type carrying the result of a
  *      flag lookup.
  *
  *----------------------------------------------------------------------
@@ -290,22 +290,26 @@ NsfFlagObjSet(
   if (objPtr->typePtr != &NsfFlagObjType) {
     TclFreeIntRep(objPtr);
     flagPtr = NEW(NsfFlag);
+    assert(flagPtr != NULL);
     /*fprintf(stderr, "NsfFlagObjSet allocated NsfFlag %p for %s\n", flagPtr, ObjStr(objPtr));*/
 
     objPtr->internalRep.twoPtrValue.ptr1 = (void *)flagPtr;
     objPtr->internalRep.twoPtrValue.ptr2 = NULL;
     objPtr->typePtr = &NsfFlagObjType;
+
   } else {
     flagPtr = (NsfFlag *)objPtr->internalRep.twoPtrValue.ptr1;
 
+    assert(flagPtr != NULL);
+
     /*fprintf(stderr, "NsfFlagObjSet %p reuses internal rep, serial (%d/%d)\n",
       objPtr, flagPtr->serial, serial);*/
 
-    if (flagPtr->payload != NULL) {DECR_REF_COUNT2("flagPtr->payload", flagPtr->payload);}
+      if (flagPtr->payload != NULL) {
+      DECR_REF_COUNT2("flagPtr->payload", flagPtr->payload);
+    }
   }
 
-  assert(flagPtr != NULL);
-
   /*
    * add values to the structure
    */
@@ -515,9 +519,9 @@ MixinregSetFromAny(
 int
 NsfMixinregGet(
     Tcl_Interp *interp,
-    Tcl_Obj *obj,
-    NsfClass **classPtr,
-    Tcl_Obj **guardObj
+    Tcl_Obj    *obj,
+    NsfClass  **classPtr,
+    Tcl_Obj   **guardObj
 ) {
 
   nonnull_assert(interp != NULL);
@@ -562,7 +566,7 @@ NsfMixinregGet(
  * NsfMixinregInvalidate --
  *
  *      MixinClasses keep a list of Tcl_Objs of type Mixinreg.
- *      When a class is deleted, this call makes sure, that
+ *      When a class is deleted, this call makes sure that
  *      non-of these have the chance to point to a stale entry.
  *
  * Results:
@@ -681,13 +685,13 @@ FilterregDupInternalRep(
   memcpy(dstPtr, srcPtr, sizeof(Filterreg));
 
   /*
-   * increment refcounts
+   * Increment refcounts
    */
   INCR_REF_COUNT2("filterregPtr->filterObj", srcPtr->filterObj);
   if (srcPtr->guardObj != NULL) {INCR_REF_COUNT2("FilterregPtr->guardObj", srcPtr->guardObj);}
 
   /*
-   * update destination obj
+   * Update destination Tcl_Obj.
    */
   dstObjPtr->typePtr = srcObjPtr->typePtr;
   dstObjPtr->internalRep.twoPtrValue.ptr1 = dstPtr;
