@@ -5,13 +5,14 @@
  *      Tcl obj-commands.
  *
  * Copyright (C) 1999-2017 Gustaf Neumann
+ * Copyright (C) 2019      Stefan Sobernig
  *
  * Vienna University of Economics and Business
  * Institute of Information Systems and New Media
  * A-1020, Welthandelsplatz 1
  * Vienna, Austria
  *
- * This work is licensed under the MIT License http://www.opensource.org/licenses/MIT
+ * This work is licensed under the MIT License https://www.opensource.org/licenses/MIT
  *
  * Copyright:
  *
@@ -69,7 +70,7 @@ NsfReplaceCommandCleanup(Tcl_Interp *interp, Tcl_Obj *nameObj, NsfShadowTclComma
   nonnull_assert(nameObj != NULL);
   nonnull_assert(ti != NULL);
 
-  /*fprintf(stderr," cleanup for %s  ti=%p in %p\n", NsfGlobalStrings[name], ti, interp);*/
+  /*fprintf(stderr, " cleanup for %s  ti=%p in %p\n", NsfGlobalStrings[name], ti, interp);*/
   cmd = Tcl_GetCommandFromObj(interp, nameObj);
   if (cmd != NULL) {
     Tcl_Command_objProc(cmd) = ti->proc;
@@ -155,7 +156,7 @@ NsfReplaceCommand(Tcl_Interp *interp, Tcl_Obj *nameObj,
   nonnull_assert(nameObj != NULL);
   nonnull_assert(ti != NULL);
 
-  /* fprintf(stderr,"NsfReplaceCommand %s\n", ObjStr(nameObj)); */
+  /* fprintf(stderr, "NsfReplaceCommand %s\n", ObjStr(nameObj)); */
   cmd = Tcl_GetCommandFromObj(interp, nameObj);
 
   if (cmd == NULL) {
@@ -260,17 +261,51 @@ Nsf_RenameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc, Tc
   /* if an obj/cl should be renamed => call the Nsf move method */
   cmd = Tcl_FindCommand(interp, ObjStr(objv[1]), (Tcl_Namespace *)NULL, 0);
   if (cmd != NULL) {
+    Tcl_ObjCmdProc *proc =  Tcl_Command_objProc(cmd);
+    ClientData clientData = Tcl_Command_objClientData(cmd);
     NsfObject *object = NsfGetObjectFromCmdPtr(cmd);
-    Tcl_Obj *methodObj = (object != NULL) ? NsfMethodObj(object, NSF_o_move_idx) : NULL;
     Tcl_Command parentCmd;
+    char *newName = ObjStr(objv[2]);
+          
+    
+    if (proc == NsfProcStub && clientData != NULL &&
+        *newName != '\0') {
+      Tcl_DString fqNewName;
+      int result;
+      NsfProcClientData *tcd = clientData;
 
-    if (object && methodObj) {
-      return NsfCallMethodWithArgs(interp, (Nsf_Object *)object,
-				   methodObj, objv[2], 1, 0, NSF_CSC_IMMEDIATE);
+      Tcl_DStringInit(&fqNewName);
+      Tcl_DStringAppend(&fqNewName, "::nsf::procs::", 14);
+      Tcl_DStringAppend(&fqNewName, newName, -1);
+      
+      /* fprintf(stderr, "oldName %s newName %s\n", ObjStr(tcd->procName), Tcl_DStringValue(&fqNewName));*/
+      result = TclRenameCommand(interp, ObjStr(tcd->procName), Tcl_DStringValue(&fqNewName));
+      
+      if (result == TCL_OK) {
+        DECR_REF_COUNT2("procNameObj", tcd->procName);
+        tcd->procName = Tcl_NewStringObj(Tcl_DStringValue(&fqNewName),
+                                         Tcl_DStringLength(&fqNewName));
+        INCR_REF_COUNT2("procNameObj", tcd->procName);
+      }
+
+      Tcl_DStringFree(&fqNewName);
+
+      if (result != TCL_OK) {
+        return TCL_ERROR;
+      }
+      
+    } else if (object != NULL) {
+      Tcl_Obj *methodObj = NsfMethodObj(object, NSF_o_move_idx);
+      
+      if (methodObj) {
+        return NsfCallMethodWithArgs(interp, (Nsf_Object *)object,
+                                     methodObj, objv[2], 1, 0,
+                                     NSF_CSC_IMMEDIATE);
+      }
     }
 
     parentCmd = Tcl_FindCommand(interp,  Tcl_Command_nsPtr(cmd)->fullName,
-			     (Tcl_Namespace *)NULL, 0);
+                                (Tcl_Namespace *)NULL, 0);
     if (parentCmd != NULL) {
       NsfObjectMethodEpochIncr("::rename");
     }
@@ -353,15 +388,17 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
 	Tcl_ListObjAppendElement(interp, listObj, ov[i+1]);
       }
 
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("object",6));
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("object", 6));
       Tcl_ListObjAppendElement(interp, listObj, cscPtr->self->cmdName);
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("class",5));
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("class", 5));
       Tcl_ListObjAppendElement(interp, listObj, (cscPtr->cl != NULL) ? cscPtr->cl->object.cmdName
 			       : NsfGlobalObjs[NSF_EMPTY]);
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("method",6));
-      Tcl_ListObjAppendElement(interp, listObj, (cscPtr->cmdPtr != NULL) ? Tcl_NewStringObj(Tcl_GetCommandName(interp, cscPtr->cmdPtr), -1)
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("method", 6));
+      Tcl_ListObjAppendElement(interp, listObj,
+                               (cscPtr->cmdPtr != NULL)
+                               ? Tcl_NewStringObj(Tcl_GetCommandName(interp, cscPtr->cmdPtr), -1)
 			       : NsfGlobalObjs[NSF_EMPTY]);
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("frametype",9));
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj("frametype", 9));
       if (cscPtr->frameType == NSF_CSC_TYPE_PLAIN) {
         frameType = "intrinsic";
       } else if (cscPtr->frameType & NSF_CSC_TYPE_ACTIVE_MIXIN) {
@@ -373,16 +410,16 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
       } else {
         frameType = "unknown";
       }
-      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(frameType,-1));
+      Tcl_ListObjAppendElement(interp, listObj, Tcl_NewStringObj(frameType, -1));
       Tcl_SetObjResult(interp, listObj);
     } else if (frameFlags & (FRAME_IS_NSF_OBJECT)) {
       NsfObject *object = (NsfObject *)Tcl_CallFrame_clientData(varFramePtr);
       /* Tcl_Obj *listObj = Tcl_NewListObj(0, NULL); */
 
-      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("object",6));
+      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("object", 6));
       Tcl_ListObjAppendElement(interp, resultObj, object->cmdName);
-      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("frameType",9));
-      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("object",6));
+      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("frameType", 9));
+      Tcl_ListObjAppendElement(interp, resultObj, Tcl_NewStringObj("object", 6));
       Tcl_SetObjResult(interp, resultObj);
     }
   }
@@ -414,11 +451,13 @@ Nsf_InfoFrameObjCmd(ClientData UNUSED(clientData), Tcl_Interp *interp, int objc,
 
 int
 NsfShadowTclCommands(Tcl_Interp *interp, NsfShadowOperations load) {
-  int rc = TCL_OK;
-  NsfRuntimeState *rst = RUNTIME_STATE(interp);
+  int              rc = TCL_OK;
+  NsfRuntimeState *rst;
 
   nonnull_assert(interp != NULL);
 
+  rst = RUNTIME_STATE(interp);
+ 
   if (load == SHADOW_LOAD) {
 
     assert(rst->tclCommands == NULL);
@@ -448,9 +487,9 @@ NsfShadowTclCommands(Tcl_Interp *interp, NsfShadowOperations load) {
     NsfReplaceCommandCheck(interp, NsfGlobalObjs[NSF_INFO_FRAME],  Nsf_InfoFrameObjCmd, CMD_INFO(rst, NSF_INFO_FRAME));
     NsfReplaceCommandCheck(interp, NsfGlobalObjs[NSF_RENAME],      Nsf_RenameObjCmd,    CMD_INFO(rst, NSF_RENAME));
   } else {
-    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_INFO_BODY], CMD_INFO(rst, NSF_INFO_BODY));
-    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_INFO_FRAME],CMD_INFO(rst, NSF_INFO_FRAME));
-    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_RENAME],    CMD_INFO(rst, NSF_RENAME));
+    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_INFO_BODY],  CMD_INFO(rst, NSF_INFO_BODY));
+    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_INFO_FRAME], CMD_INFO(rst, NSF_INFO_FRAME));
+    NsfReplaceCommandCleanup(interp, NsfGlobalObjs[NSF_RENAME],     CMD_INFO(rst, NSF_RENAME));
 
     FREE(NsfShadowTclCommandInfo*, rst->tclCommands);
     rst->tclCommands = NULL;
@@ -482,7 +521,7 @@ int NsfCallCommand(Tcl_Interp *interp, NsfGlobalNames name,
   ALLOC_ON_STACK(Tcl_Obj*, objc, ov);
   /*
    {int i;
-    fprintf(stderr,"calling %s (%p %p) in %p, objc=%d ",
+    fprintf(stderr, "calling %s (%p %p) in %p, objc=%d ",
 	    NsfGlobalStrings[name], ti, ti->proc, interp, objc);
             for(i=0;i<objc;i++){fprintf(stderr, "'%s' ", ObjStr(objv[i]));}
     fprintf(stderr, "\n");
