@@ -5,7 +5,7 @@
 #
 package require nx
 package require nsf::mongo
-package provide nx::mongo 2.2
+package provide nx::mongo 2.3
 
 # todo: How to handle multiple connections; currently we have a single, global connection,
 # todo: All references are currently auto-fetched. Make this optional.
@@ -223,8 +223,9 @@ namespace eval ::nx::mongo {
     }
 
     #
-    # The methods "bson encode|decode" perform the low level type
-    # mapping. For now, this handles just the array notation.
+    # The methods "bson encode|decode" perform the low-level type
+    # mapping between NX objects and the bson serialization. For now,
+    # this handles just the array notation.
     #
     :public method "bson decode" {bsontype value} {
       #puts stderr "bson decode of ${:name} /$bsontype/ '$value'"
@@ -710,6 +711,7 @@ namespace eval ::nx::mongo {
       {-orderby ""}
       {-limit:integer}
       {-skip:integer}
+      {-asJSON:boolean 0}
     } {
       set result [list]
       set opts [list]
@@ -719,10 +721,31 @@ namespace eval ::nx::mongo {
                        [:bson cond $cond] \
                        -opts [:bson opts -orderby $orderby -atts $atts {*}$opts] ]
 
-      foreach tuple $fetched {
-        lappend result [:bson create $tuple]
+      if {$asJSON} {
+        #
+        # Return fetched tuples form mongoDB in form of a JSON array
+        # (between square brackets).
+        #
+        # The last 5 lines of this proc could be written as the following line,
+        # but we keep it traditional...
+        #
+        # return [subst { \[ [join [lmap tuple $fetched {mongo::json::generate $tuple}] ,\n] \] }]
+        #
+        set tuples [list]
+        foreach tuple $fetched {
+          lappend tuples [mongo::json::generate $tuple]
+        }
+        return [subst { \[ [join $tuples ",\n"] \] }]
+
+      } else {
+        #
+        # Create from the fetched tuples form mongoDB objects.
+        #
+        foreach tuple $fetched {
+          lappend result [:bson create $tuple]
+        }
+        return $result
       }
-      return $result
     }
 
     :public method show {
@@ -898,6 +921,14 @@ namespace eval ::nx::mongo {
       return $bson
     }
 
+    :public method "bson asJSON" {} {
+      #
+      # Return the current object in JSON syntax.
+      #
+      return [mongo::json::generate [:bson encode]]
+    }
+
+
     #
     # destroy a mapped object from memory
     #
