@@ -1,7 +1,7 @@
 package require nx
 
-package require XOTcl 2.2
-package provide nx::serializer 2.2
+package require XOTcl 2.3
+package provide nx::serializer 2.3
 
 # For the time being, we require classical XOTcl.
 
@@ -63,7 +63,7 @@ namespace eval ::nx::serializer {
       in addition to provide pairs of old-string and new-string
       (like in the Tcl command <@tt>string map</@tt>). This option
       can be used to regenerate the serialized object under a different
-      object or under an different name, or to translate relative
+      object or under a different name, or to translate relative
       object names in the serialized code.<p>
 
       Examples:
@@ -1052,7 +1052,6 @@ namespace eval ::nx::serializer {
 
     set :rootClass ::xotcl::Object
     set :rootMetaClass ::xotcl::Class
-    #array set :ignorePattern [list "::xotcl::*" 1]
     array set :ignorePattern [list "::nsf::*" 1 "::nx::*" 1 "::xotcl::*" 1]
 
     :public object method serialize-all-start {s} {
@@ -1210,6 +1209,21 @@ namespace eval ::nx::serializer {
           [:frameWorkCmd ::nsf::relation::get $o class-mixin] \
           [:frameWorkCmd ::nsf::method::assertion $o class-invar]
 
+      #
+      # Check for overloaded accessors generated by the slots and make sure, these are
+      # available in the serialized code.
+      #
+      set slotObjects [nsf::directdispatch $o ::nsf::methods::class::info::slotobjects -type ::nx::Slot]
+      foreach so $slotObjects {
+        set methodName [namespace tail $so]
+        if {[$o info instprocs $methodName] ne ""} {
+          #
+          # The method was overloaded.
+          #
+          $s addPostCmd [:method-serialize $o $methodName inst $s]
+        }
+      }
+
       $s addPostCmd [:frameWorkCmd ::nsf::relation::get $o class-filter]
       return $cmd
     }
