@@ -1,19 +1,19 @@
-# -*- tcl -*-
+# -*- Tcl -*-
 ############################################################
 # xotcl2.tcl --
 #
 #      Implementation of the XOTcl 2 object system, based
 #      on the Next Scripting Framework (NSF).
 #
-# Copyright (C) 2010-2016 Gustaf Neumann
-# Copyright (C) 2010-2016 Stefan Sobernig
+# Copyright (C) 2010-2016      Gustaf Neumann
+# Copyright (C) 2010-2016,2019 Stefan Sobernig
 #
 # Vienna University of Economics and Business
 # Institute of Information Systems and New Media
 # A-1020, Welthandelsplatz 1
 # Vienna, Austria
 # 
-# This work is licensed under the MIT License http://www.opensource.org/licenses/MIT
+# This work is licensed under the MIT License https://www.opensource.org/licenses/MIT
 #
 # Copyright:
 #
@@ -38,8 +38,8 @@
 # SOFTWARE.
 #
 
-package provide XOTcl 2.1.0
 package require nx
+package provide XOTcl 2.3
 
 #######################################################
 # Classical ::xotcl*
@@ -48,7 +48,7 @@ namespace eval ::xotcl {
   #
   # Set XOTcl version variables
   #
-  set ::xotcl::version 2.1
+  set ::xotcl::version 2.3
   set ::xotcl::patchlevel .0
 
   namespace eval ::nsf {}            ;# make pkg-indexer happy
@@ -97,12 +97,12 @@ namespace eval ::xotcl {
 
   proc ::xotcl::self {{arg ""}} {
       switch $arg {
-	"" {uplevel ::nsf::self}
+	"" {::uplevel ::nsf::self}
 	next {
-	  set handle [uplevel ::nsf::current nextmethod]
+	  set handle [::uplevel ::nsf::current nextmethod]
 	  method_handle_to_xotcl $handle
 	}
-	default {uplevel ::nsf::current $arg}
+	default {::uplevel ::nsf::current $arg}
       }
   }
 
@@ -127,7 +127,7 @@ namespace eval ::xotcl {
 # ::nsf::method::alias Object unknown       ::nsf::methods::object::unknown
   ::nsf::method::alias Object uplevel       ::nsf::methods::object::uplevel
   ::nsf::method::alias Object upvar         ::nsf::methods::object::upvar
-  ::nsf::method::alias Object volatile      ::nsf::methods::object::volatile
+  ::nsf::method::alias Object volatile      ::nsf::methods::object::volatile1
 
   #
   # object methods
@@ -163,7 +163,7 @@ namespace eval ::xotcl {
 
   # @method ::xotcl::Object#cleanup
   #
-  # TODO: this is a method not used in the Next Scripting Langauge. This
+  # TODO: this is a method not used in the Next Scripting Language. This
   # method is just called via recreate, so everything necessary can be
   # performed there as well. However, it is available for backward
   # compatibility available in XOTcl 2.0
@@ -177,7 +177,7 @@ namespace eval ::xotcl {
   # namespaces are cleared, and the object's relationships (e.g., mixin
   # relations) are reset.
   #
-  # @properties interally-called
+  # @properties internally-called
 
   # @method ::xotcl::Object#destroy
   #
@@ -219,7 +219,7 @@ namespace eval ::xotcl {
   # This bypassing feature comes handy when streaming an object into a
   # scripted form (e.g., by using the bundled Serializer). Upon
   # deserializing the object, using the {{{noinit}}} flag helps you to
-  # preserve the serialized object state (rather then having the
+  # preserve the serialized object state (rather than having the
   # object re-initialized).
 
   # @method ::xotcl::Object#requireNamespace
@@ -374,7 +374,7 @@ namespace eval ::xotcl {
     target:optional args
   } {
     set arglist [list]
-    if {[info exists target] && [string range $target 0 0] eq "-"} {
+    if {[info exists target] && [string index $target 0] eq "-"} {
       error "target '$target' must not start with a dash"
     }
     if {[info exists default]} {lappend arglist -default $default}
@@ -398,7 +398,7 @@ namespace eval ::xotcl {
     target:optional args
   } {
     set arglist [list]
-    if {[info exists target] && [string range $target 0 0] eq "-"} {
+    if {[info exists target] && [string index $target 0] eq "-"} {
       error "target '$target' must not start with a dash"
     }
     if {[info exists default]} {lappend arglist -default $default}
@@ -422,7 +422,7 @@ namespace eval ::xotcl {
     if {[::nsf::current isnextcall]} {
       set lvl [::nsf::current callinglevel]
     }
-    uplevel $lvl [list [self] create {*}$args]
+    ::uplevel $lvl [list [self] create {*}$args]
   }
 
   Object instproc unknown {m args} {
@@ -431,7 +431,7 @@ namespace eval ::xotcl {
     }
   }
 
-  # "init" must exist on Object. per default it is empty.
+  # "init" must exist on Object. Per default it is empty.
   Object instproc init args {
     if {![::nsf::current isnextcall] && [llength $args] > 0 && [::nsf::configure debug] > 0} {
       ::nsf::log Warning "Arguments '$args' to constructor of object [self] are most likely not processed"
@@ -644,8 +644,8 @@ namespace eval ::xotcl {
         argName [$o ::nsf::methods::${scope}::info::method args $method] \
         flag    [$o ::nsf::methods::${scope}::info::method parameter $method] {
           if {$argName eq $arg} {
-	    # we are in a proc, so using builtin "upvar" is safe
-	    upvar $varName default
+	    # we are in a proc, so using built-in "upvar" is safe
+	    ::upvar $varName default
             if {[llength $flag] == 2} {
               set default [lindex $flag 1]
               #puts "--- get $scope default for $o $method $arg => setting default to '$default'"
@@ -925,7 +925,7 @@ namespace eval ::xotcl {
   # definition of "xotcl::Class slots", based on contains
   ::xotcl::Class instproc slots {cmd} {
     set slotContainer [::nx::slotObj [self]]
-    uplevel [list [self] contains -object $slotContainer $cmd]
+    ::uplevel [list [self] contains -object $slotContainer $cmd]
   }
 
   #
@@ -1062,8 +1062,8 @@ namespace eval ::xotcl {
   ::nsf::method::create ::xotcl::Class -per-object __unknown {name} {}
   ::nsf::object::unknown::add xotcl {::xotcl::Class __unknown}
 
-  proc myproc {args} {linsert $args 0 [uplevel ::nsf::self]}
-  proc myvar  {var}  {[uplevel ::nsf::self] requireNamespace; return [uplevel ::nsf::self]::$var}
+  proc myproc {args} {linsert $args 0 [::uplevel ::nsf::self]}
+  proc myvar  {var}  {[::uplevel ::nsf::self] requireNamespace; return [::uplevel ::nsf::self]::$var}
 
   #
   # create ::xotcl::MetaSlot for better compatibility with XOTcl 1
@@ -1080,7 +1080,7 @@ namespace eval ::xotcl {
 
     #
     # As NX/XOTcl hybrids, all slot kinds would not inherit the
-    # unknown behaviour of ::xotcl::Class. Therefore, we provide it
+    # unknown behavior of ::xotcl::Class. Therefore, we provide it
     # explicitly to slots for backward compatibility ...
     #
     :public alias unknown ::nsf::classes::xotcl::Class::unknown
@@ -1095,7 +1095,7 @@ namespace eval ::xotcl {
 
     #:property defaultmethods {get set}
 
-    :property {substdefault true}
+    :property {substdefault}
     :property -accessor public multivalued {
       #
       # The slot object is an nx object, therefore we need the nx
@@ -1179,6 +1179,9 @@ namespace eval ::xotcl {
       # passed. Since nx does not allow this, we simply ignore the passed
       # arguments $args.
       #
+      if {[info exists :default] && ![info exists :substdefault]} {
+        set :substdefault 0b111
+      }
       nsf::next ""
     }
 
@@ -1247,7 +1250,7 @@ namespace eval ::xotcl {
     set oc 0
     set mc 0
     foreach file [glob -nocomplain -- {*}$args] {
-      if {[catch {set f [open $file]} msg]} then {
+      if {[catch {set f [open $file]} msg]} {
         catch {close $f}
         cd $old
         error $msg
@@ -1294,7 +1297,7 @@ namespace eval ::xotcl {
   #
   Object instproc extractConfigureArg {al name {cutTheArg 0}} {
     set value ""
-    upvar $al argList
+    ::upvar $al argList
     set largs [llength $argList]
     for {set i 0} {$i < $largs} {incr i} {
       if {[lindex $argList $i] == $name && $i + 1 < $largs} {
@@ -1426,7 +1429,7 @@ namespace eval ::xotcl {
         }
         set :component $pkg
         lappend :uses($prevComponent) ${:component}
-        set v [uplevel \#1 [set :packagecmd] require $args]
+        set v [::uplevel \#1 [set :packagecmd] require $args]
         if {$v ne "" && ${:verbose}} {
         set path [lindex [::package ifneeded $pkg $v] 1]
           puts "... $pkg $v loaded from '$path'"
