@@ -24,9 +24,9 @@ if {[info exists opt(-testlog)]} {
   puts "\nRegression Test Summary of $opt(-title):"
   puts "\tEnvironment: Tcl $tcl_patchLevel, OS $tcl_platform(os) $tcl_platform(osVersion)\
 	machine $tcl_platform(machine) threaded [info exists tcl_platform(threaded)]."
-  puts "\tNSF [package req nsf] (commit $::nsf::commit) performed $tests tests in $files files, success $success, failures $failures in [expr {$ms / 1000.0}] seconds"
+  puts "\tNSF [package req nsf] (commit [::nsf::pkgconfig get commit]) performed $tests tests in $files files, success $success, failures $failures in [expr {$ms / 1000.0}] seconds"
   if {$failures == 0} {
-    puts "\tCongratulations, all tests of $opt(-title) passed in your installation of NSF [package req nsf] (commit $::nsf::commit)"
+    puts "\tCongratulations, all tests of $opt(-title) passed in your installation of NSF [package req nsf] (commit [::nsf::pkgconfig get commit])"
   }
   puts ""
 }
